
# RMAKE SCRIPT

def prebuild():
    print("如果你想自定义预构建流程，请你修改/.rmmp/Rmake.py.")

def postbuild():
    print("如果你想自定义构建后的逻辑，请修改/.rmmp/Rmake.py")

# def build():
    '''
    if you want to use you own build script, you can define a build function here
    '''
